.. _drizcr:

*********************************
Step 7: Cosmic-ray identification
*********************************
The cosmic rays and bad pixels are now identified by comparing the input images with the associated blotted,median-cleaned images created.

.. automodule:: drizzlepac.drizCR  
   :members:
   :undoc-members:
